@@ -165,14 +165,18 @@ def mat2DF(mat, column_names=None, row_names=None):
         if len(np.shape(mat)) == 1:
             mat = np.reshape(mat, (len(mat), 1))
         if column_names is None:
-            if ("NamedArray" in str(type(mat))):
+            if hasattr(mat, "colnames"):
                 column_names = mat.colnames
-            else:
-                column_names = range(np.shape(mat)[1])
+        if column_names is not None:
+            if len(column_names) == 0:
+                column_names = None
         if row_names is None:
-            if ("NamedArray" in str(type(mat))):
+            if hasattr(mat, "rownames"):
                 if len(mat.rownames) > 0:
                     row_names = mat.rownames
+        if row_names is not None:
+            if len(row_names) == 0:
+                row_names = None
         df = pd.DataFrame(mat, columns=column_names, index=row_names)
     return df
 
